@@ -1,5 +1,5 @@
 
-#' Clear cached results
+#' Cache options
 #'
 #' Clears the local cache of downloaded files (by default in the
 #' ec.cache folder in the working directory).
@@ -11,12 +11,30 @@
 #' @examples
 #' clear_cache()
 #'
-clear_cache <- function(cache='ec.cache') {
+clear_cache <- function(cache = "ec.cache") {
   if(dir.exists(cache)) {
-    unlink(cache, recursive=TRUE)
+    unlink(cache, recursive = TRUE)
   }
 }
 
+# create environment for session cache options
+cache_options <- new.env(parent = emptyenv())
+cache_options$default_cache <- "ec.cache"
+
+#' @rdname clear_cache
+#' @export
+set_default_cache <- function(cache = "ec.cache") {
+  old_cache <- get_default_cache()
+  cache_options$default_cache <- cache
+  invisible(old_cache)
+}
+
+#' @rdname clear_cache
+#' @export
+get_default_cache <- function() {
+  cache_options$default_cache
+}
+
 put_cached <- function(cache, url, data) {
   url_hash <- digest::digest(url)
   if(!dir.exists(cache) && !is.null(data)) {
@@ -26,7 +44,7 @@ put_cached <- function(cache, url, data) {
   if(is.null(data) && file.exists(fname)) {
     unlink(fname)
   } else if(!is.null(data)) {
-    write(data, fname)
+    readr::write_file(data, fname)
   }
 }
 
@@ -34,7 +52,7 @@ get_cached <- function(cache, url) {
   url_hash <- digest::digest(url)
   fname <- file.path(cache, paste0(url_hash, ".csv"))
   if(file.exists(fname)) {
-    paste(readLines(fname), collapse="\n")
+    readr::read_file(fname)
   } else {
     NULL
   }
